import os

from applitools import logger
from applitools.eyes import Eyes
from applitools.geometry import Region
from applitools.logger import StdoutLogger

logger.set_logger(StdoutLogger())
eyes = Eyes()
eyes.api_key = os.environ['APPLITOOLS_API_KEY']

try:
    eyes.open(None, "Python Images", "First image test")
    with open("MY_IMAGE.png", 'rb') as f:
        image = f.read()
    eyes.check_image(image, None, "home")
    eyes.check_image(image, Region(left=330, top=140, width=510, height=380), "My region")
    eyes.close()
finally:
    eyes.abort_if_not_closed()



class MockSwitchTo:
    def __init__(self):
        pass

    def default_content(self):
        pass

    def frames(self, frame_chain):
        pass


class MockWebDriver:
    def __init__(self):
        self.viewport_size = None
        self.capabilities = {'takesScreenshot': True}

    # noinspection PyMethodMayBeStatic
    def get_frame_chain(self):
        return []

    # noinspection PyMethodMayBeStatic
    def execute_script(self, script):
        return None

    def get_window_size(self):
        return self.viewport_size

    def quit(self):
        pass

    @property
    def switch_to(self):
        return MockSwitchTo()





